public inbox for linux-kernel@vger.kernel.org
 help / color / mirror / Atom feed
* [PATCH] drm/panel: samsung-atna33xc20: extend msleep in atana33xc20_disable to avoid glitch
@ 2025-04-25 10:58 Alvin1 Chen
  2025-04-25 15:15 ` Ilpo Järvinen
  0 siblings, 1 reply; 3+ messages in thread
From: Alvin1 Chen @ 2025-04-25 10:58 UTC (permalink / raw)
  To: platform-driver-x86; +Cc: linux-kernel, Alvin1 Chen

samsung-atna40ct03 encouters glitch when powering off, extend msleep
in atana33xc20_disable to 40 can avoid this symptom.

Change-Id: I4d052621d3c3e0fdae0ac472fe5da151f46be237
Signed-off-by: Alvin1 Chen <alvin1.chen@lcfc.corp-partner.google.com>
---
 drivers/gpu/drm/panel/panel-samsung-atna33xc20.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/drivers/gpu/drm/panel/panel-samsung-atna33xc20.c b/drivers/gpu/drm/panel/panel-samsung-atna33xc20.c
index 9a482a744b8c..87a4e1c47aaa 100644
--- a/drivers/gpu/drm/panel/panel-samsung-atna33xc20.c
+++ b/drivers/gpu/drm/panel/panel-samsung-atna33xc20.c
@@ -154,10 +154,10 @@ static int atana33xc20_disable(struct drm_panel *panel)
 	p->el3_was_on = true;
 
 	/*
 	 * Sleeping 20 ms here (after setting the GPIO) avoids a glitch when
 	 * powering off.
 	 */
-	msleep(20);
+	msleep(40);
 
 	return 0;
 }
@@ -154,10 +154,10 @@ static int atana33xc20_disable(struct drm_panel *panel)
 
 	/*
-	 * Sleeping 20 ms here (after setting the GPIO) avoids a glitch when
+	 * Sleeping 40 ms here (after setting the GPIO) avoids a glitch when
 	 * powering off.
 	 */
-- 
2.34.1


^ permalink raw reply related	[flat|nested] 3+ messages in thread
* [PATCH] drm/panel: samsung-atna33xc20: extend msleep in atana33xc20_disable to avoid glitch
@ 2025-01-22 11:31 Alvin1 Chen
  0 siblings, 0 replies; 3+ messages in thread
From: Alvin1 Chen @ 2025-01-22 11:31 UTC (permalink / raw)
  To: neil.armstrong; +Cc: quic_jesszhan, linux-kernel, Alvin1 Chen

samsung-atna40ct03 encouters glitch when powering off, extned msleep
in atana33xc20_disable to 40 can avoid this symptom.

Signed-off-by: Alvin1 Chen <alvin1.chen@lcfc.corp-partner.google.com>
---
 drivers/gpu/drm/panel/panel-samsung-atna33xc20.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/drivers/gpu/drm/panel/panel-samsung-atna33xc20.c b/drivers/gpu/drm/panel/panel-samsung-atna33xc20.c
index 9a482a744b8c1..87a4e1c47aaaa 100644
--- a/drivers/gpu/drm/panel/panel-samsung-atna33xc20.c
+++ b/drivers/gpu/drm/panel/panel-samsung-atna33xc20.c
@@ -154,10 +154,10 @@ static int atana33xc20_disable(struct drm_panel *panel)
 	p->el3_was_on = true;
 
 	/*
 	 * Sleeping 20 ms here (after setting the GPIO) avoids a glitch when
 	 * powering off.
 	 */
-	msleep(20);
+	msleep(40);
 
 	return 0;
 }
@@ -154,10 +154,10 @@ static int atana33xc20_disable(struct drm_panel *panel)
 
 	/*
-	 * Sleeping 20 ms here (after setting the GPIO) avoids a glitch when
+	 * Sleeping 40 ms here (after setting the GPIO) avoids a glitch when
 	 * powering off.
 	 */
-- 
2.34.1


^ permalink raw reply related	[flat|nested] 3+ messages in thread

end of thread, other threads:[~2025-04-25 15:15 UTC | newest]

Thread overview: 3+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2025-04-25 10:58 [PATCH] drm/panel: samsung-atna33xc20: extend msleep in atana33xc20_disable to avoid glitch Alvin1 Chen
2025-04-25 15:15 ` Ilpo Järvinen
  -- strict thread matches above, loose matches on Subject: below --
2025-01-22 11:31 Alvin1 Chen

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox